(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/common'), require('@angular/core'), require('@angular-three/core'), require('rxjs'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('@angular-three/core/canvas', ['exports', '@angular/common', '@angular/core', '@angular-three/core', 'rxjs', 'rxjs/operators'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global['angular-three'] = global['angular-three'] || {}, global['angular-three'].core = global['angular-three'].core || {}, global['angular-three'].core.canvas = {}), global.ng.common, global.ng.core, global['angular-three'].core, global.rxjs, global.rxjs.operators));
}(this, (function (exports, common, core, core$1, rxjs, operators) { 'use strict';

    var CanvasComponent = /** @class */ (function () {
        function CanvasComponent(canvasStore, animationStore, eventsStore, loopService, ngZone, hostElement, renderer, document, destroyed) {
            this.canvasStore = canvasStore;
            this.animationStore = animationStore;
            this.eventsStore = eventsStore;
            this.loopService = loopService;
            this.ngZone = ngZone;
            this.hostElement = hostElement;
            this.renderer = renderer;
            this.document = document;
            this.destroyed = destroyed;
            this.hostClass = true;
            this.raycaster = {};
            this.created = new core.EventEmitter();
            canvasStore.setSize({
                width: hostElement.nativeElement.clientWidth,
                height: hostElement.nativeElement.clientHeight,
            });
        }
        Object.defineProperty(CanvasComponent.prototype, "orthographic", {
            set: function (v) {
                this.canvasStore.setIsOrthographic(v);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CanvasComponent.prototype, "linear", {
            set: function (v) {
                this.canvasStore.setIsLinear(v);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CanvasComponent.prototype, "shadows", {
            set: function (v) {
                this.canvasStore.setShadows(v);
            },
            enumerable: false,
            configurable: true
        });
        CanvasComponent.prototype.ngOnInit = function () {
            var _this = this;
            this.ngZone.runOutsideAngular(function () {
                _this.canvasStore.initRendererEffect(_this.rendererCanvas.nativeElement);
                _this.canvasStore.initSceneEffect(_this.scene);
                _this.canvasStore.initCameraEffect(_this.camera);
                _this.canvasStore.initRaycasterEffect(_this.raycaster);
                _this.initWindowResizeListener();
                _this.initActiveListener();
            });
        };
        CanvasComponent.prototype.ngOnDestroy = function () {
            if (this.windowResizeListener) {
                this.windowResizeListener();
            }
        };
        CanvasComponent.prototype.initWindowResizeListener = function () {
            var _this = this;
            this.windowResizeListener = this.renderer.listen(this.document.defaultView, 'resize', function () {
                var _a;
                _this.canvasStore.windowResizeEffect({
                    size: {
                        width: _this.hostElement.nativeElement.clientWidth,
                        height: _this.hostElement.nativeElement.clientHeight,
                    },
                    dpr: ((_a = _this.document.defaultView) === null || _a === void 0 ? void 0 : _a.devicePixelRatio) || 0,
                });
            });
        };
        CanvasComponent.prototype.initActiveListener = function () {
            var _this = this;
            this.canvasStore.active$
                .pipe(operators.takeUntil(this.destroyed), operators.observeOn(rxjs.asyncScheduler))
                .subscribe(function (active) {
                if (active) {
                    var _b = _this.canvasStore.getImperativeState(), renderer = _b.renderer, camera = _b.camera, scene = _b.scene;
                    if (renderer && camera && scene) {
                        _this.created.emit({ gl: renderer, camera: camera, scene: scene });
                        _this.eventsStore.connectEffect(renderer.domElement);
                        _this.loopService.start();
                    }
                }
            });
        };
        return CanvasComponent;
    }());
    CanvasComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ngt-canvas',
                    exportAs: 'ngtCanvas',
                    template: " <canvas #rendererCanvas></canvas> ",
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    providers: [
                        core$1.CanvasStore,
                        core$1.EventsStore,
                        core$1.InstancesStore,
                        core$1.AnimationStore,
                        core$1.LoopService,
                        core$1.DestroyedService,
                    ],
                    styles: ["\n      :host {\n        display: block;\n        position: relative;\n        width: 100%;\n        height: 100%;\n        overflow: hidden;\n      }\n\n      :host canvas {\n        display: block;\n      }\n    "]
                },] }
    ];
    CanvasComponent.ctorParameters = function () { return [
        { type: core$1.CanvasStore, decorators: [{ type: core.Self }] },
        { type: core$1.AnimationStore, decorators: [{ type: core.Self }] },
        { type: core$1.EventsStore, decorators: [{ type: core.Self }] },
        { type: core$1.LoopService, decorators: [{ type: core.Self }] },
        { type: core.NgZone },
        { type: core.ElementRef },
        { type: core.Renderer2 },
        { type: undefined, decorators: [{ type: core.Inject, args: [common.DOCUMENT,] }] },
        { type: core$1.DestroyedService }
    ]; };
    CanvasComponent.propDecorators = {
        hostClass: [{ type: core.HostBinding, args: ['class.ngt-canvas',] }],
        orthographic: [{ type: core.Input }],
        linear: [{ type: core.Input }],
        shadows: [{ type: core.Input }],
        camera: [{ type: core.Input }],
        scene: [{ type: core.Input }],
        raycaster: [{ type: core.Input }],
        created: [{ type: core.Output }],
        rendererCanvas: [{ type: core.ViewChild, args: ['rendererCanvas', { static: true },] }]
    };

    var ThreeCanvasModule = /** @class */ (function () {
        function ThreeCanvasModule() {
        }
        return ThreeCanvasModule;
    }());
    ThreeCanvasModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [CanvasComponent],
                    exports: [CanvasComponent],
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.CanvasComponent = CanvasComponent;
    exports.ThreeCanvasModule = ThreeCanvasModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-three-core-canvas.umd.js.map
