import { ThreeBufferGeometry } from '@angular-three/core/geometries';
import { Directive, Input, NgZone, Optional, } from '@angular/core';
import { InterleavedBufferAttribute } from 'three';
export class InterleavedBufferAttributeDirective {
    constructor(ngZone, geometryDirective) {
        this.ngZone = ngZone;
        this.geometryDirective = geometryDirective;
    }
    ngOnChanges() {
        this.ngZone.runOutsideAngular(() => {
            if (this.attribute) {
                this.attribute.needsUpdate = true;
            }
        });
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            if (this.geometryDirective && this.attach) {
                this._attribute = new InterleavedBufferAttribute(...this.args);
                if (this.attribute) {
                    this.geometryDirective.bufferGeometry.setAttribute(this.attach, this.attribute);
                }
            }
        });
    }
    ngOnDestroy() {
        this.ngZone.runOutsideAngular(() => {
            if (this.geometryDirective && this.attach) {
                this.geometryDirective.bufferGeometry.deleteAttribute(this.attach);
            }
        });
    }
    get attribute() {
        return this._attribute;
    }
}
InterleavedBufferAttributeDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-interleavedBufferAttribute',
                exportAs: 'ngtInterleavedBufferAttribute',
            },] }
];
InterleavedBufferAttributeDirective.ctorParameters = () => [
    { type: NgZone },
    { type: ThreeBufferGeometry, decorators: [{ type: Optional }] }
];
InterleavedBufferAttributeDirective.propDecorators = {
    args: [{ type: Input }],
    attach: [{ type: Input }]
};
//# sourceMappingURL=interleaved-buffer-attribute.directive.js.map