import { Directive, EventEmitter, NgZone, Output, } from '@angular/core';
import { Object3D } from 'three';
import { AnimationStore } from '../stores';
export class AnimationLoopParticipant {
    constructor(animationStore, ngZone) {
        this.animationStore = animationStore;
        this.ngZone = ngZone;
        this.animateReady = new EventEmitter();
    }
    participate(animateObject) {
        this.ngZone.runOutsideAngular(() => {
            if (this.animateReady.observers.length) {
                if (animateObject instanceof Object3D) {
                    this.animateTeardown = this.animationStore.registerAnimation(animateObject, (obj, state) => {
                        this.animateReady.emit({
                            animateObject: obj,
                            renderState: state,
                        });
                    });
                }
                else {
                    this.animateTeardown = this.animationStore.registerAnimation((state) => {
                        this.animateReady.emit({
                            animateObject,
                            renderState: state,
                        });
                    });
                }
            }
        });
    }
    ngOnDestroy() {
        this.ngZone.runOutsideAngular(() => {
            if (this.animateTeardown) {
                this.animateTeardown();
            }
        });
    }
}
AnimationLoopParticipant.decorators = [
    { type: Directive }
];
AnimationLoopParticipant.ctorParameters = () => [
    { type: AnimationStore },
    { type: NgZone }
];
AnimationLoopParticipant.propDecorators = {
    animateReady: [{ type: Output }]
};
//# sourceMappingURL=animation-loop-participant.abstract.js.map