import { Injectable } from '@angular/core';
import { Clock } from 'three';
import { AnimationStore, CanvasStore } from '../stores';
export class LoopService {
    constructor(canvasStore, animationStore) {
        this.canvasStore = canvasStore;
        this.animationStore = animationStore;
        this.loopClock = new Clock();
    }
    start() {
        const { renderer } = this.canvasStore.getImperativeState();
        if (renderer) {
            renderer.setAnimationLoop(() => {
                this.tick(this.loopClock.getDelta());
            });
        }
    }
    stop() {
        const { renderer } = this.canvasStore.getImperativeState();
        if (renderer) {
            renderer.setAnimationLoop(null);
        }
    }
    tick(delta) {
        const { renderer, scene, camera, internal, clock, } = this.canvasStore.getImperativeState();
        const { animationCallbacks, hasPriority, } = this.animationStore.getImperativeState();
        if (renderer && scene && camera) {
            if (hasPriority) {
                animationCallbacks.sort(({ priority: a = 0 }, { priority: b = 0 }) => a - b);
            }
            else {
                renderer.render(scene, camera);
            }
            for (const animationCallback of animationCallbacks) {
                if (animationCallback.obj) {
                    animationCallback.callback(animationCallback.obj, {
                        clock,
                        camera,
                        scene,
                        renderer,
                        size: internal.size,
                        delta,
                    });
                }
                else {
                    animationCallback.callback({
                        clock,
                        camera,
                        scene,
                        renderer,
                        size: internal.size,
                        delta,
                    });
                }
            }
        }
    }
    ngOnDestroy() {
        this.stop();
    }
}
LoopService.decorators = [
    { type: Injectable }
];
LoopService.ctorParameters = () => [
    { type: CanvasStore },
    { type: AnimationStore }
];
//# sourceMappingURL=loop.service.js.map