import { ThreeBufferGeometry } from '@angular-three/core/geometries';
import { Directive, NgZone, Optional, Input, NgModule } from '@angular/core';
import { CatmullRomCurve3, CubicBezierCurve, CubicBezierCurve3, EllipseCurve, LineCurve, LineCurve3, QuadraticBezierCurve, QuadraticBezierCurve3, SplineCurve } from 'three';
import { CommonModule } from '@angular/common';

class ThreeCurve {
    constructor(ngZone, geometryDirective) {
        this.ngZone = ngZone;
        this.geometryDirective = geometryDirective;
        this._extraArgs = [];
    }
    set extraArgs(v) {
        this._extraArgs = v;
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            this._curve = new this.curveType(...this._extraArgs);
            if (this.curve && this.geometryDirective) {
                const points = this.curve.getPoints(this.divisions);
                this.geometryDirective.bufferGeometry.setFromPoints(points);
            }
        });
    }
    get curve() {
        return this._curve;
    }
}
ThreeCurve.decorators = [
    { type: Directive }
];
ThreeCurve.ctorParameters = () => [
    { type: NgZone },
    { type: ThreeBufferGeometry, decorators: [{ type: Optional }] }
];
ThreeCurve.propDecorators = {
    divisions: [{ type: Input }]
};

// GENERATED
class CatmullRomCurve3Directive extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = CatmullRomCurve3;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CatmullRomCurve3Directive.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-catmullRomCurve3',
                exportAs: 'ngtCatmullRomCurve3',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: CatmullRomCurve3Directive,
                    },
                ],
            },] }
];
CatmullRomCurve3Directive.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCatmullRomCurve3Module {
}
ThreeCatmullRomCurve3Module.decorators = [
    { type: NgModule, args: [{
                declarations: [CatmullRomCurve3Directive],
                imports: [CommonModule],
                exports: [CatmullRomCurve3Directive],
            },] }
];

// GENERATED

// GENERATED
class CubicBezierCurveDirective extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = CubicBezierCurve;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CubicBezierCurveDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-cubicBezierCurve',
                exportAs: 'ngtCubicBezierCurve',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: CubicBezierCurveDirective,
                    },
                ],
            },] }
];
CubicBezierCurveDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCubicBezierCurveModule {
}
ThreeCubicBezierCurveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CubicBezierCurveDirective],
                imports: [CommonModule],
                exports: [CubicBezierCurveDirective],
            },] }
];

// GENERATED

// GENERATED
class CubicBezierCurve3Directive extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = CubicBezierCurve3;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CubicBezierCurve3Directive.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-cubicBezierCurve3',
                exportAs: 'ngtCubicBezierCurve3',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: CubicBezierCurve3Directive,
                    },
                ],
            },] }
];
CubicBezierCurve3Directive.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCubicBezierCurve3Module {
}
ThreeCubicBezierCurve3Module.decorators = [
    { type: NgModule, args: [{
                declarations: [CubicBezierCurve3Directive],
                imports: [CommonModule],
                exports: [CubicBezierCurve3Directive],
            },] }
];

// GENERATED

// GENERATED
class EllipseCurveDirective extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = EllipseCurve;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
EllipseCurveDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-ellipseCurve',
                exportAs: 'ngtEllipseCurve',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: EllipseCurveDirective,
                    },
                ],
            },] }
];
EllipseCurveDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeEllipseCurveModule {
}
ThreeEllipseCurveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [EllipseCurveDirective],
                imports: [CommonModule],
                exports: [EllipseCurveDirective],
            },] }
];

// GENERATED

// GENERATED
class LineCurveDirective extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = LineCurve;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
LineCurveDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lineCurve',
                exportAs: 'ngtLineCurve',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: LineCurveDirective,
                    },
                ],
            },] }
];
LineCurveDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeLineCurveModule {
}
ThreeLineCurveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LineCurveDirective],
                imports: [CommonModule],
                exports: [LineCurveDirective],
            },] }
];

// GENERATED

// GENERATED
class LineCurve3Directive extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = LineCurve3;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
LineCurve3Directive.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lineCurve3',
                exportAs: 'ngtLineCurve3',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: LineCurve3Directive,
                    },
                ],
            },] }
];
LineCurve3Directive.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeLineCurve3Module {
}
ThreeLineCurve3Module.decorators = [
    { type: NgModule, args: [{
                declarations: [LineCurve3Directive],
                imports: [CommonModule],
                exports: [LineCurve3Directive],
            },] }
];

// GENERATED

// GENERATED
class QuadraticBezierCurveDirective extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = QuadraticBezierCurve;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
QuadraticBezierCurveDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-quadraticBezierCurve',
                exportAs: 'ngtQuadraticBezierCurve',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: QuadraticBezierCurveDirective,
                    },
                ],
            },] }
];
QuadraticBezierCurveDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeQuadraticBezierCurveModule {
}
ThreeQuadraticBezierCurveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [QuadraticBezierCurveDirective],
                imports: [CommonModule],
                exports: [QuadraticBezierCurveDirective],
            },] }
];

// GENERATED

// GENERATED
class QuadraticBezierCurve3Directive extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = QuadraticBezierCurve3;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
QuadraticBezierCurve3Directive.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-quadraticBezierCurve3',
                exportAs: 'ngtQuadraticBezierCurve3',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: QuadraticBezierCurve3Directive,
                    },
                ],
            },] }
];
QuadraticBezierCurve3Directive.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeQuadraticBezierCurve3Module {
}
ThreeQuadraticBezierCurve3Module.decorators = [
    { type: NgModule, args: [{
                declarations: [QuadraticBezierCurve3Directive],
                imports: [CommonModule],
                exports: [QuadraticBezierCurve3Directive],
            },] }
];

// GENERATED

// GENERATED
class SplineCurveDirective extends ThreeCurve {
    constructor() {
        super(...arguments);
        this.curveType = SplineCurve;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
SplineCurveDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-splineCurve',
                exportAs: 'ngtSplineCurve',
                providers: [
                    {
                        provide: ThreeCurve,
                        useExisting: SplineCurveDirective,
                    },
                ],
            },] }
];
SplineCurveDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeSplineCurveModule {
}
ThreeSplineCurveModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SplineCurveDirective],
                imports: [CommonModule],
                exports: [SplineCurveDirective],
            },] }
];

// GENERATED

// GENERATED

/**
 * Generated bundle index. Do not edit.
 */

export { CatmullRomCurve3Directive, CubicBezierCurve3Directive, CubicBezierCurveDirective, EllipseCurveDirective, LineCurve3Directive, LineCurveDirective, QuadraticBezierCurve3Directive, QuadraticBezierCurveDirective, SplineCurveDirective, ThreeCatmullRomCurve3Module, ThreeCubicBezierCurve3Module, ThreeCubicBezierCurveModule, ThreeCurve, ThreeEllipseCurveModule, ThreeLineCurve3Module, ThreeLineCurveModule, ThreeQuadraticBezierCurve3Module, ThreeQuadraticBezierCurveModule, ThreeSplineCurveModule };
//# sourceMappingURL=angular-three-core-curves.js.map
