import { InstancesStore } from '@angular-three/core';
import { Directive, SkipSelf, NgZone, Input, NgModule } from '@angular/core';
import { InstancedBufferGeometry, BoxBufferGeometry, CircleBufferGeometry, ConeBufferGeometry, CylinderBufferGeometry, DodecahedronBufferGeometry, ExtrudeBufferGeometry, IcosahedronBufferGeometry, LatheBufferGeometry, OctahedronBufferGeometry, ParametricBufferGeometry, PlaneBufferGeometry, PolyhedronBufferGeometry, RingBufferGeometry, ShapeBufferGeometry, SphereBufferGeometry, TetrahedronBufferGeometry, TextBufferGeometry, TorusBufferGeometry, TorusKnotBufferGeometry, TubeBufferGeometry, WireframeGeometry, EdgesGeometry } from 'three';
import { CommonModule } from '@angular/common';

class ThreeBufferGeometry {
    constructor(instancesStore, ngZone) {
        this.instancesStore = instancesStore;
        this.ngZone = ngZone;
        this._extraArgs = [];
    }
    set extraArgs(v) {
        this._extraArgs = v;
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            this._bufferGeometry = new this.geometryType(...this._extraArgs);
            this.instancesStore.saveBufferGeometry({
                id: this.ngtId,
                bufferGeometry: this._bufferGeometry,
            });
        });
    }
    get bufferGeometry() {
        return this._bufferGeometry;
    }
    ngOnDestroy() {
        this.ngZone.runOutsideAngular(() => {
            if (this.bufferGeometry) {
                this.instancesStore.removeBufferGeometry(this.ngtId || this.bufferGeometry.uuid);
                this.bufferGeometry.dispose();
            }
        });
    }
}
ThreeBufferGeometry.decorators = [
    { type: Directive }
];
ThreeBufferGeometry.ctorParameters = () => [
    { type: InstancesStore, decorators: [{ type: SkipSelf }] },
    { type: NgZone }
];
ThreeBufferGeometry.propDecorators = {
    ngtId: [{ type: Input }]
};

// GENERATED
class InstancedBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = InstancedBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
InstancedBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-instancedBufferGeometry,ngt-instancedGeometry',
                exportAs: 'ngtInstancedBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: InstancedBufferGeometryDirective,
                    },
                ],
            },] }
];
InstancedBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeInstancedBufferGeometryModule {
}
ThreeInstancedBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InstancedBufferGeometryDirective],
                imports: [CommonModule],
                exports: [InstancedBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class BoxBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = BoxBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
BoxBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-boxBufferGeometry,ngt-boxGeometry',
                exportAs: 'ngtBoxBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: BoxBufferGeometryDirective,
                    },
                ],
            },] }
];
BoxBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeBoxBufferGeometryModule {
}
ThreeBoxBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [BoxBufferGeometryDirective],
                imports: [CommonModule],
                exports: [BoxBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class CircleBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = CircleBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CircleBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-circleBufferGeometry,ngt-circleGeometry',
                exportAs: 'ngtCircleBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: CircleBufferGeometryDirective,
                    },
                ],
            },] }
];
CircleBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCircleBufferGeometryModule {
}
ThreeCircleBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CircleBufferGeometryDirective],
                imports: [CommonModule],
                exports: [CircleBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class ConeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ConeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ConeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-coneBufferGeometry,ngt-coneGeometry',
                exportAs: 'ngtConeBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: ConeBufferGeometryDirective,
                    },
                ],
            },] }
];
ConeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeConeBufferGeometryModule {
}
ThreeConeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ConeBufferGeometryDirective],
                imports: [CommonModule],
                exports: [ConeBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class CylinderBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = CylinderBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CylinderBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-cylinderBufferGeometry,ngt-cylinderGeometry',
                exportAs: 'ngtCylinderBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: CylinderBufferGeometryDirective,
                    },
                ],
            },] }
];
CylinderBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCylinderBufferGeometryModule {
}
ThreeCylinderBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CylinderBufferGeometryDirective],
                imports: [CommonModule],
                exports: [CylinderBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class DodecahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = DodecahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DodecahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-dodecahedronBufferGeometry,ngt-dodecahedronGeometry',
                exportAs: 'ngtDodecahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: DodecahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
DodecahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeDodecahedronBufferGeometryModule {
}
ThreeDodecahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DodecahedronBufferGeometryDirective],
                imports: [CommonModule],
                exports: [DodecahedronBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class ExtrudeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ExtrudeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ExtrudeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-extrudeBufferGeometry,ngt-extrudeGeometry',
                exportAs: 'ngtExtrudeBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: ExtrudeBufferGeometryDirective,
                    },
                ],
            },] }
];
ExtrudeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeExtrudeBufferGeometryModule {
}
ThreeExtrudeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ExtrudeBufferGeometryDirective],
                imports: [CommonModule],
                exports: [ExtrudeBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class IcosahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = IcosahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
IcosahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-icosahedronBufferGeometry,ngt-icosahedronGeometry',
                exportAs: 'ngtIcosahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: IcosahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
IcosahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeIcosahedronBufferGeometryModule {
}
ThreeIcosahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [IcosahedronBufferGeometryDirective],
                imports: [CommonModule],
                exports: [IcosahedronBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class LatheBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = LatheBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
LatheBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-latheBufferGeometry,ngt-latheGeometry',
                exportAs: 'ngtLatheBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: LatheBufferGeometryDirective,
                    },
                ],
            },] }
];
LatheBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeLatheBufferGeometryModule {
}
ThreeLatheBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LatheBufferGeometryDirective],
                imports: [CommonModule],
                exports: [LatheBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class OctahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = OctahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
OctahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-octahedronBufferGeometry,ngt-octahedronGeometry',
                exportAs: 'ngtOctahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: OctahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
OctahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeOctahedronBufferGeometryModule {
}
ThreeOctahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [OctahedronBufferGeometryDirective],
                imports: [CommonModule],
                exports: [OctahedronBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class ParametricBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ParametricBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ParametricBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-parametricBufferGeometry,ngt-parametricGeometry',
                exportAs: 'ngtParametricBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: ParametricBufferGeometryDirective,
                    },
                ],
            },] }
];
ParametricBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeParametricBufferGeometryModule {
}
ThreeParametricBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ParametricBufferGeometryDirective],
                imports: [CommonModule],
                exports: [ParametricBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class PlaneBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = PlaneBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
PlaneBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-planeBufferGeometry,ngt-planeGeometry',
                exportAs: 'ngtPlaneBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: PlaneBufferGeometryDirective,
                    },
                ],
            },] }
];
PlaneBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreePlaneBufferGeometryModule {
}
ThreePlaneBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PlaneBufferGeometryDirective],
                imports: [CommonModule],
                exports: [PlaneBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class PolyhedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = PolyhedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
PolyhedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-polyhedronBufferGeometry,ngt-polyhedronGeometry',
                exportAs: 'ngtPolyhedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: PolyhedronBufferGeometryDirective,
                    },
                ],
            },] }
];
PolyhedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreePolyhedronBufferGeometryModule {
}
ThreePolyhedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PolyhedronBufferGeometryDirective],
                imports: [CommonModule],
                exports: [PolyhedronBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class RingBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = RingBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
RingBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-ringBufferGeometry,ngt-ringGeometry',
                exportAs: 'ngtRingBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: RingBufferGeometryDirective,
                    },
                ],
            },] }
];
RingBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeRingBufferGeometryModule {
}
ThreeRingBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RingBufferGeometryDirective],
                imports: [CommonModule],
                exports: [RingBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class ShapeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = ShapeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
ShapeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-shapeBufferGeometry,ngt-shapeGeometry',
                exportAs: 'ngtShapeBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: ShapeBufferGeometryDirective,
                    },
                ],
            },] }
];
ShapeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeShapeBufferGeometryModule {
}
ThreeShapeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ShapeBufferGeometryDirective],
                imports: [CommonModule],
                exports: [ShapeBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class SphereBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = SphereBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
SphereBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-sphereBufferGeometry,ngt-sphereGeometry',
                exportAs: 'ngtSphereBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: SphereBufferGeometryDirective,
                    },
                ],
            },] }
];
SphereBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeSphereBufferGeometryModule {
}
ThreeSphereBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SphereBufferGeometryDirective],
                imports: [CommonModule],
                exports: [SphereBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class TetrahedronBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TetrahedronBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TetrahedronBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-tetrahedronBufferGeometry,ngt-tetrahedronGeometry',
                exportAs: 'ngtTetrahedronBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: TetrahedronBufferGeometryDirective,
                    },
                ],
            },] }
];
TetrahedronBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeTetrahedronBufferGeometryModule {
}
ThreeTetrahedronBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TetrahedronBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TetrahedronBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class TextBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TextBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TextBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-textBufferGeometry,ngt-textGeometry',
                exportAs: 'ngtTextBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: TextBufferGeometryDirective,
                    },
                ],
            },] }
];
TextBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeTextBufferGeometryModule {
}
ThreeTextBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TextBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TextBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class TorusBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TorusBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TorusBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-torusBufferGeometry,ngt-torusGeometry',
                exportAs: 'ngtTorusBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: TorusBufferGeometryDirective,
                    },
                ],
            },] }
];
TorusBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeTorusBufferGeometryModule {
}
ThreeTorusBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TorusBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TorusBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class TorusKnotBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TorusKnotBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TorusKnotBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-torusKnotBufferGeometry,ngt-torusKnotGeometry',
                exportAs: 'ngtTorusKnotBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: TorusKnotBufferGeometryDirective,
                    },
                ],
            },] }
];
TorusKnotBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeTorusKnotBufferGeometryModule {
}
ThreeTorusKnotBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TorusKnotBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TorusKnotBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class TubeBufferGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = TubeBufferGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
TubeBufferGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-tubeBufferGeometry,ngt-tubeGeometry',
                exportAs: 'ngtTubeBufferGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: TubeBufferGeometryDirective,
                    },
                ],
            },] }
];
TubeBufferGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeTubeBufferGeometryModule {
}
ThreeTubeBufferGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TubeBufferGeometryDirective],
                imports: [CommonModule],
                exports: [TubeBufferGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class WireframeGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = WireframeGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
WireframeGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-wireframeGeometry',
                exportAs: 'ngtWireframeGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: WireframeGeometryDirective,
                    },
                ],
            },] }
];
WireframeGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeWireframeGeometryModule {
}
ThreeWireframeGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [WireframeGeometryDirective],
                imports: [CommonModule],
                exports: [WireframeGeometryDirective],
            },] }
];

// GENERATED

// GENERATED
class EdgesGeometryDirective extends ThreeBufferGeometry {
    constructor() {
        super(...arguments);
        this.geometryType = EdgesGeometry;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
EdgesGeometryDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-edgesGeometry',
                exportAs: 'ngtEdgesGeometry',
                providers: [
                    {
                        provide: ThreeBufferGeometry,
                        useExisting: EdgesGeometryDirective,
                    },
                ],
            },] }
];
EdgesGeometryDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeEdgesGeometryModule {
}
ThreeEdgesGeometryModule.decorators = [
    { type: NgModule, args: [{
                declarations: [EdgesGeometryDirective],
                imports: [CommonModule],
                exports: [EdgesGeometryDirective],
            },] }
];

// GENERATED

// GENERATED

/**
 * Generated bundle index. Do not edit.
 */

export { BoxBufferGeometryDirective, CircleBufferGeometryDirective, ConeBufferGeometryDirective, CylinderBufferGeometryDirective, DodecahedronBufferGeometryDirective, EdgesGeometryDirective, ExtrudeBufferGeometryDirective, IcosahedronBufferGeometryDirective, InstancedBufferGeometryDirective, LatheBufferGeometryDirective, OctahedronBufferGeometryDirective, ParametricBufferGeometryDirective, PlaneBufferGeometryDirective, PolyhedronBufferGeometryDirective, RingBufferGeometryDirective, ShapeBufferGeometryDirective, SphereBufferGeometryDirective, TetrahedronBufferGeometryDirective, TextBufferGeometryDirective, ThreeBoxBufferGeometryModule, ThreeBufferGeometry, ThreeCircleBufferGeometryModule, ThreeConeBufferGeometryModule, ThreeCylinderBufferGeometryModule, ThreeDodecahedronBufferGeometryModule, ThreeEdgesGeometryModule, ThreeExtrudeBufferGeometryModule, ThreeIcosahedronBufferGeometryModule, ThreeInstancedBufferGeometryModule, ThreeLatheBufferGeometryModule, ThreeOctahedronBufferGeometryModule, ThreeParametricBufferGeometryModule, ThreePlaneBufferGeometryModule, ThreePolyhedronBufferGeometryModule, ThreeRingBufferGeometryModule, ThreeShapeBufferGeometryModule, ThreeSphereBufferGeometryModule, ThreeTetrahedronBufferGeometryModule, ThreeTextBufferGeometryModule, ThreeTorusBufferGeometryModule, ThreeTorusKnotBufferGeometryModule, ThreeTubeBufferGeometryModule, ThreeWireframeGeometryModule, TorusBufferGeometryDirective, TorusKnotBufferGeometryDirective, TubeBufferGeometryDirective, WireframeGeometryDirective };
//# sourceMappingURL=angular-three-core-geometries.js.map
