import { ThreeObject3d } from '@angular-three/core';
import { Directive, Input, NgModule } from '@angular/core';
import { LightProbe, AmbientLight, AmbientLightProbe, HemisphereLight, HemisphereLightProbe, DirectionalLight, PointLight, SpotLight, RectAreaLight } from 'three';
import { CommonModule } from '@angular/common';

class ThreeLight extends ThreeObject3d {
    constructor() {
        super(...arguments);
        this._extraArgs = [];
    }
    set extraArgs(v) {
        this._extraArgs = v;
    }
    ngOnInit() {
        this.init();
    }
    initObject() {
        if (this.intensity) {
            this._extraArgs[1] = this.intensity;
        }
        this._light = new this.lightType(...this._extraArgs);
    }
    get object3d() {
        return this._light;
    }
}
ThreeLight.decorators = [
    { type: Directive }
];
ThreeLight.propDecorators = {
    intensity: [{ type: Input }]
};

// GENERATED
class LightProbeDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = LightProbe;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
LightProbeDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lightProbe',
                exportAs: 'ngtLightProbe',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: LightProbeDirective,
                    },
                ],
            },] }
];
LightProbeDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeLightProbeModule {
}
ThreeLightProbeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LightProbeDirective],
                imports: [CommonModule],
                exports: [LightProbeDirective],
            },] }
];

// GENERATED

// GENERATED
class AmbientLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = AmbientLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
AmbientLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-ambientLight',
                exportAs: 'ngtAmbientLight',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: AmbientLightDirective,
                    },
                ],
            },] }
];
AmbientLightDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeAmbientLightModule {
}
ThreeAmbientLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AmbientLightDirective],
                imports: [CommonModule],
                exports: [AmbientLightDirective],
            },] }
];

// GENERATED

// GENERATED
class AmbientLightProbeDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = AmbientLightProbe;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
AmbientLightProbeDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-ambientLightProbe',
                exportAs: 'ngtAmbientLightProbe',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: AmbientLightProbeDirective,
                    },
                ],
            },] }
];
AmbientLightProbeDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeAmbientLightProbeModule {
}
ThreeAmbientLightProbeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AmbientLightProbeDirective],
                imports: [CommonModule],
                exports: [AmbientLightProbeDirective],
            },] }
];

// GENERATED

// GENERATED
class HemisphereLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = HemisphereLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
HemisphereLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-hemisphereLight',
                exportAs: 'ngtHemisphereLight',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: HemisphereLightDirective,
                    },
                ],
            },] }
];
HemisphereLightDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeHemisphereLightModule {
}
ThreeHemisphereLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [HemisphereLightDirective],
                imports: [CommonModule],
                exports: [HemisphereLightDirective],
            },] }
];

// GENERATED

// GENERATED
class HemisphereLightProbeDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = HemisphereLightProbe;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
HemisphereLightProbeDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-hemisphereLightProbe',
                exportAs: 'ngtHemisphereLightProbe',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: HemisphereLightProbeDirective,
                    },
                ],
            },] }
];
HemisphereLightProbeDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeHemisphereLightProbeModule {
}
ThreeHemisphereLightProbeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [HemisphereLightProbeDirective],
                imports: [CommonModule],
                exports: [HemisphereLightProbeDirective],
            },] }
];

// GENERATED

// GENERATED
class DirectionalLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = DirectionalLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DirectionalLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-directionalLight',
                exportAs: 'ngtDirectionalLight',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: DirectionalLightDirective,
                    },
                ],
            },] }
];
DirectionalLightDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeDirectionalLightModule {
}
ThreeDirectionalLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DirectionalLightDirective],
                imports: [CommonModule],
                exports: [DirectionalLightDirective],
            },] }
];

// GENERATED

// GENERATED
class PointLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = PointLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
PointLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-pointLight',
                exportAs: 'ngtPointLight',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: PointLightDirective,
                    },
                ],
            },] }
];
PointLightDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreePointLightModule {
}
ThreePointLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PointLightDirective],
                imports: [CommonModule],
                exports: [PointLightDirective],
            },] }
];

// GENERATED

// GENERATED
class SpotLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = SpotLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
SpotLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-spotLight',
                exportAs: 'ngtSpotLight',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: SpotLightDirective,
                    },
                ],
            },] }
];
SpotLightDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeSpotLightModule {
}
ThreeSpotLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SpotLightDirective],
                imports: [CommonModule],
                exports: [SpotLightDirective],
            },] }
];

// GENERATED

// GENERATED
class RectAreaLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = RectAreaLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
RectAreaLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-rectAreaLight',
                exportAs: 'ngtRectAreaLight',
                providers: [
                    {
                        provide: ThreeObject3d,
                        useExisting: RectAreaLightDirective,
                    },
                ],
            },] }
];
RectAreaLightDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeRectAreaLightModule {
}
ThreeRectAreaLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RectAreaLightDirective],
                imports: [CommonModule],
                exports: [RectAreaLightDirective],
            },] }
];

// GENERATED

// GENERATED

/**
 * Generated bundle index. Do not edit.
 */

export { AmbientLightDirective, AmbientLightProbeDirective, DirectionalLightDirective, HemisphereLightDirective, HemisphereLightProbeDirective, LightProbeDirective, PointLightDirective, RectAreaLightDirective, SpotLightDirective, ThreeAmbientLightModule, ThreeAmbientLightProbeModule, ThreeDirectionalLightModule, ThreeHemisphereLightModule, ThreeHemisphereLightProbeModule, ThreeLight, ThreeLightProbeModule, ThreePointLightModule, ThreeRectAreaLightModule, ThreeSpotLightModule };
//# sourceMappingURL=angular-three-core-lights.js.map
