import { ThreeObject3dMaterialGeometry, ThreeObject3d } from '@angular-three/core';
import { ThreeBufferGeometry } from '@angular-three/core/geometries';
import { ThreeMaterial } from '@angular-three/core/materials';
import { Directive, ContentChildren, ContentChild, NgModule } from '@angular/core';
import { Line, LineLoop, LineSegments } from 'three';
import { CommonModule } from '@angular/common';

class ThreeLine extends ThreeObject3dMaterialGeometry {
    set materialDirectives(v) {
        if (this.material == null && v) {
            this.material =
                v.length === 1
                    ? v.first.material
                    : v.toArray().map((dir) => dir.material);
        }
    }
    set bufferGeometryDirective(v) {
        if (this.geometry == null) {
            this.geometry = v.bufferGeometry;
        }
    }
    get objectType() {
        return this.lineType;
    }
}
ThreeLine.decorators = [
    { type: Directive }
];
ThreeLine.propDecorators = {
    materialDirectives: [{ type: ContentChildren, args: [ThreeMaterial,] }],
    bufferGeometryDirective: [{ type: ContentChild, args: [ThreeBufferGeometry,] }]
};

class LineDirective extends ThreeLine {
    constructor() {
        super(...arguments);
        this.lineType = Line;
    }
}
LineDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-line',
                exportAs: 'ngtLine',
                providers: [
                    { provide: ThreeObject3d, useExisting: LineDirective },
                ],
            },] }
];

class ThreeLineModule {
}
ThreeLineModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LineDirective],
                imports: [CommonModule],
                exports: [LineDirective],
            },] }
];

class LineLoopDirective extends ThreeLine {
    constructor() {
        super(...arguments);
        this.lineType = LineLoop;
    }
}
LineLoopDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lineLoop',
                exportAs: 'ngtLineLoop',
                providers: [{ provide: ThreeObject3d, useExisting: LineLoopDirective }],
            },] }
];

class ThreeLineLoopModule {
}
ThreeLineLoopModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LineLoopDirective],
                imports: [CommonModule],
                exports: [LineLoopDirective],
            },] }
];

class LineSegmentsDirective extends ThreeLine {
    constructor() {
        super(...arguments);
        this.lineType = LineSegments;
    }
}
LineSegmentsDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lineSegments',
                exportAs: 'ngtLineSegments',
                providers: [{ provide: ThreeObject3d, useExisting: LineSegmentsDirective }],
            },] }
];

class ThreeLineSegmentsModule {
}
ThreeLineSegmentsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LineSegmentsDirective],
                imports: [CommonModule],
                exports: [LineSegmentsDirective],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { LineDirective, LineLoopDirective, LineSegmentsDirective, ThreeLine, ThreeLineLoopModule, ThreeLineModule, ThreeLineSegmentsModule };
//# sourceMappingURL=angular-three-core-lines.js.map
