import { defer, from, of } from 'rxjs';
import { tap } from 'rxjs/operators';
import { BufferGeometryLoader, FontLoader } from 'three';

const bufferGeometryLoader = new BufferGeometryLoader();
function loadBufferGeometry(data, onLoad) {
    return defer(() => {
        if (typeof data === 'string')
            return from(bufferGeometryLoader.loadAsync(data));
        return of(bufferGeometryLoader.parse(data));
    }).pipe(tap((geometry) => {
        if (onLoad)
            onLoad(geometry);
    }));
}

const fontLoader = new FontLoader();
function loadFont(dataOrUrl, onLoad) {
    return defer(() => {
        if (typeof dataOrUrl === 'string')
            return from(fontLoader.loadAsync(dataOrUrl));
        return of(fontLoader.parse(dataOrUrl));
    }).pipe(tap((font) => {
        if (onLoad) {
            onLoad(font);
        }
    }));
}

/**
 * Generated bundle index. Do not edit.
 */

export { loadBufferGeometry, loadFont };
//# sourceMappingURL=angular-three-core-loaders.js.map
