import { InstancesStore, CanvasStore } from '@angular-three/core';
import { Directive, NgZone, SkipSelf, Input, NgModule } from '@angular/core';
import { Color, ShadowMaterial, SpriteMaterial, RawShaderMaterial, ShaderMaterial, PointsMaterial, MeshPhysicalMaterial, MeshStandardMaterial, MeshPhongMaterial, MeshToonMaterial, MeshNormalMaterial, MeshLambertMaterial, MeshDepthMaterial, MeshDistanceMaterial, MeshBasicMaterial, MeshMatcapMaterial, LineDashedMaterial, LineBasicMaterial } from 'three';
import { CommonModule } from '@angular/common';

class ThreeMaterial {
    constructor(ngZone, instancesStore, canvasStore) {
        this.ngZone = ngZone;
        this.instancesStore = instancesStore;
        this.canvasStore = canvasStore;
    }
    set parameters(v) {
        this._parameters = v;
        if (v && this.material) {
            this.ngZone.runOutsideAngular(() => {
                this.convertColorToLinear(v);
                this.material.setValues(v);
                this.material.needsUpdate = true;
            });
        }
    }
    get parameters() {
        return this._parameters;
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            if (this.parameters) {
                this.convertColorToLinear(this.parameters);
            }
            this._material = new this.materialType(this.parameters);
            this.instancesStore.saveMaterial({
                id: this.ngtId,
                material: this._material,
            });
        });
    }
    get material() {
        return this._material;
    }
    convertColorToLinear(parameters) {
        if ('color' in parameters) {
            const colorParams = parameters['color'];
            parameters['color'] = Array.isArray(colorParams)
                ? new Color(...colorParams)
                : new Color(colorParams);
            if (!this.canvasStore.getImperativeState().isLinear) {
                parameters['color'].convertSRGBToLinear();
            }
        }
    }
    ngOnDestroy() {
        this.ngZone.runOutsideAngular(() => {
            if (this.material) {
                this.instancesStore.removeMaterial(this.ngtId || this.material.uuid);
                this.material.dispose();
            }
        });
    }
}
ThreeMaterial.decorators = [
    { type: Directive }
];
ThreeMaterial.ctorParameters = () => [
    { type: NgZone },
    { type: InstancesStore, decorators: [{ type: SkipSelf }] },
    { type: CanvasStore, decorators: [{ type: SkipSelf }] }
];
ThreeMaterial.propDecorators = {
    ngtId: [{ type: Input }],
    parameters: [{ type: Input }]
};

// GENERATED
class ShadowMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = ShadowMaterial;
    }
}
ShadowMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-shadowMaterial',
                exportAs: 'ngtShadowMaterial',
                providers: [{ provide: ThreeMaterial, useExisting: ShadowMaterialDirective }],
            },] }
];

// GENERATED
class ThreeShadowMaterialModule {
}
ThreeShadowMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ShadowMaterialDirective],
                imports: [CommonModule],
                exports: [ShadowMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class SpriteMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = SpriteMaterial;
    }
}
SpriteMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-spriteMaterial',
                exportAs: 'ngtSpriteMaterial',
                providers: [{ provide: ThreeMaterial, useExisting: SpriteMaterialDirective }],
            },] }
];

// GENERATED
class ThreeSpriteMaterialModule {
}
ThreeSpriteMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SpriteMaterialDirective],
                imports: [CommonModule],
                exports: [SpriteMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class RawShaderMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = RawShaderMaterial;
    }
}
RawShaderMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-rawShaderMaterial',
                exportAs: 'ngtRawShaderMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: RawShaderMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeRawShaderMaterialModule {
}
ThreeRawShaderMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RawShaderMaterialDirective],
                imports: [CommonModule],
                exports: [RawShaderMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class ShaderMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = ShaderMaterial;
    }
}
ShaderMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-shaderMaterial',
                exportAs: 'ngtShaderMaterial',
                providers: [{ provide: ThreeMaterial, useExisting: ShaderMaterialDirective }],
            },] }
];

// GENERATED
class ThreeShaderMaterialModule {
}
ThreeShaderMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ShaderMaterialDirective],
                imports: [CommonModule],
                exports: [ShaderMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class PointsMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = PointsMaterial;
    }
}
PointsMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-pointsMaterial',
                exportAs: 'ngtPointsMaterial',
                providers: [{ provide: ThreeMaterial, useExisting: PointsMaterialDirective }],
            },] }
];

// GENERATED
class ThreePointsMaterialModule {
}
ThreePointsMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PointsMaterialDirective],
                imports: [CommonModule],
                exports: [PointsMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshPhysicalMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshPhysicalMaterial;
    }
}
MeshPhysicalMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshPhysicalMaterial',
                exportAs: 'ngtMeshPhysicalMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshPhysicalMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshPhysicalMaterialModule {
}
ThreeMeshPhysicalMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshPhysicalMaterialDirective],
                imports: [CommonModule],
                exports: [MeshPhysicalMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshStandardMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshStandardMaterial;
    }
}
MeshStandardMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshStandardMaterial',
                exportAs: 'ngtMeshStandardMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshStandardMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshStandardMaterialModule {
}
ThreeMeshStandardMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshStandardMaterialDirective],
                imports: [CommonModule],
                exports: [MeshStandardMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshPhongMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshPhongMaterial;
    }
}
MeshPhongMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshPhongMaterial',
                exportAs: 'ngtMeshPhongMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshPhongMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshPhongMaterialModule {
}
ThreeMeshPhongMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshPhongMaterialDirective],
                imports: [CommonModule],
                exports: [MeshPhongMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshToonMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshToonMaterial;
    }
}
MeshToonMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshToonMaterial',
                exportAs: 'ngtMeshToonMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshToonMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshToonMaterialModule {
}
ThreeMeshToonMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshToonMaterialDirective],
                imports: [CommonModule],
                exports: [MeshToonMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshNormalMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshNormalMaterial;
    }
}
MeshNormalMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshNormalMaterial',
                exportAs: 'ngtMeshNormalMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshNormalMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshNormalMaterialModule {
}
ThreeMeshNormalMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshNormalMaterialDirective],
                imports: [CommonModule],
                exports: [MeshNormalMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshLambertMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshLambertMaterial;
    }
}
MeshLambertMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshLambertMaterial',
                exportAs: 'ngtMeshLambertMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshLambertMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshLambertMaterialModule {
}
ThreeMeshLambertMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshLambertMaterialDirective],
                imports: [CommonModule],
                exports: [MeshLambertMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshDepthMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshDepthMaterial;
    }
}
MeshDepthMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshDepthMaterial',
                exportAs: 'ngtMeshDepthMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshDepthMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshDepthMaterialModule {
}
ThreeMeshDepthMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshDepthMaterialDirective],
                imports: [CommonModule],
                exports: [MeshDepthMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshDistanceMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshDistanceMaterial;
    }
}
MeshDistanceMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshDistanceMaterial',
                exportAs: 'ngtMeshDistanceMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshDistanceMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshDistanceMaterialModule {
}
ThreeMeshDistanceMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshDistanceMaterialDirective],
                imports: [CommonModule],
                exports: [MeshDistanceMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshBasicMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshBasicMaterial;
    }
}
MeshBasicMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshBasicMaterial',
                exportAs: 'ngtMeshBasicMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshBasicMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshBasicMaterialModule {
}
ThreeMeshBasicMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshBasicMaterialDirective],
                imports: [CommonModule],
                exports: [MeshBasicMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class MeshMatcapMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = MeshMatcapMaterial;
    }
}
MeshMatcapMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-meshMatcapMaterial',
                exportAs: 'ngtMeshMatcapMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: MeshMatcapMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeMeshMatcapMaterialModule {
}
ThreeMeshMatcapMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MeshMatcapMaterialDirective],
                imports: [CommonModule],
                exports: [MeshMatcapMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class LineDashedMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = LineDashedMaterial;
    }
}
LineDashedMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lineDashedMaterial',
                exportAs: 'ngtLineDashedMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: LineDashedMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeLineDashedMaterialModule {
}
ThreeLineDashedMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LineDashedMaterialDirective],
                imports: [CommonModule],
                exports: [LineDashedMaterialDirective],
            },] }
];

// GENERATED

// GENERATED
class LineBasicMaterialDirective extends ThreeMaterial {
    constructor() {
        super(...arguments);
        this.materialType = LineBasicMaterial;
    }
}
LineBasicMaterialDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-lineBasicMaterial',
                exportAs: 'ngtLineBasicMaterial',
                providers: [
                    { provide: ThreeMaterial, useExisting: LineBasicMaterialDirective },
                ],
            },] }
];

// GENERATED
class ThreeLineBasicMaterialModule {
}
ThreeLineBasicMaterialModule.decorators = [
    { type: NgModule, args: [{
                declarations: [LineBasicMaterialDirective],
                imports: [CommonModule],
                exports: [LineBasicMaterialDirective],
            },] }
];

// GENERATED

// GENERATED

/**
 * Generated bundle index. Do not edit.
 */

export { LineBasicMaterialDirective, LineDashedMaterialDirective, MeshBasicMaterialDirective, MeshDepthMaterialDirective, MeshDistanceMaterialDirective, MeshLambertMaterialDirective, MeshMatcapMaterialDirective, MeshNormalMaterialDirective, MeshPhongMaterialDirective, MeshPhysicalMaterialDirective, MeshStandardMaterialDirective, MeshToonMaterialDirective, PointsMaterialDirective, RawShaderMaterialDirective, ShaderMaterialDirective, ShadowMaterialDirective, SpriteMaterialDirective, ThreeLineBasicMaterialModule, ThreeLineDashedMaterialModule, ThreeMaterial, ThreeMeshBasicMaterialModule, ThreeMeshDepthMaterialModule, ThreeMeshDistanceMaterialModule, ThreeMeshLambertMaterialModule, ThreeMeshMatcapMaterialModule, ThreeMeshNormalMaterialModule, ThreeMeshPhongMaterialModule, ThreeMeshPhysicalMaterialModule, ThreeMeshStandardMaterialModule, ThreeMeshToonMaterialModule, ThreePointsMaterialModule, ThreeRawShaderMaterialModule, ThreeShaderMaterialModule, ThreeShadowMaterialModule, ThreeSpriteMaterialModule };
//# sourceMappingURL=angular-three-core-materials.js.map
