import { ThreeObject3d } from '@angular-three/core';
import { Directive, Input, ContentChild, NgModule } from '@angular/core';
import { SpriteMaterial, Sprite } from 'three';
import { ThreeMaterial } from '@angular-three/core/materials';
import { CommonModule } from '@angular/common';

class ThreeSprite extends ThreeObject3d {
    ngAfterContentInit() {
        this.init();
    }
    initObject() {
        if (this.material) {
            this._sprite = new this.spriteType(this.material);
            return;
        }
        if (this.materialDirective) {
            if (this.materialDirective.material instanceof SpriteMaterial) {
                this._sprite = new this.spriteType(this.materialDirective.material);
                return;
            }
            console.warn(`Sprite can only be instantiated with SpriteMaterial`);
        }
    }
    get object3d() {
        return this._sprite;
    }
}
ThreeSprite.decorators = [
    { type: Directive }
];
ThreeSprite.propDecorators = {
    material: [{ type: Input }],
    materialDirective: [{ type: ContentChild, args: [ThreeMaterial,] }]
};

class SpriteDirective extends ThreeSprite {
    constructor() {
        super(...arguments);
        this.spriteType = Sprite;
    }
}
SpriteDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-sprite',
                exportAs: 'ngtSprite',
                providers: [
                    { provide: ThreeObject3d, useExisting: SpriteDirective },
                ],
            },] }
];

class ThreeSpriteModule {
}
ThreeSpriteModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SpriteDirective],
                imports: [CommonModule],
                exports: [SpriteDirective],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { SpriteDirective, ThreeSprite, ThreeSpriteModule };
//# sourceMappingURL=angular-three-core-sprites.js.map
