import { Directive, NgZone, Input, NgModule } from '@angular/core';
import { CanvasTexture, CompressedTexture, CubeTexture, DataTexture, DataTexture2DArray, DataTexture3D, DepthTexture, VideoTexture } from 'three';
import { CommonModule } from '@angular/common';

class ThreeTexture {
    constructor(ngZone) {
        this.ngZone = ngZone;
        this._extraArgs = [];
    }
    set extraArgs(v) {
        this._extraArgs = v;
    }
    ngOnInit() {
        this.ngZone.runOutsideAngular(() => {
            this._texture = new this.textureType(...this._extraArgs);
        });
    }
    get texture() {
        return this._texture;
    }
    ngOnDestroy() {
        this.ngZone.runOutsideAngular(() => {
            if (this.texture) {
                this.texture.dispose();
            }
        });
    }
}
ThreeTexture.decorators = [
    { type: Directive }
];
ThreeTexture.ctorParameters = () => [
    { type: NgZone }
];

// GENERATED
class CanvasTextureDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = CanvasTexture;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CanvasTextureDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-canvasTexture',
                exportAs: 'ngtCanvasTexture',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: CanvasTextureDirective,
                    },
                ],
            },] }
];
CanvasTextureDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCanvasTextureModule {
}
ThreeCanvasTextureModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CanvasTextureDirective],
                imports: [CommonModule],
                exports: [CanvasTextureDirective],
            },] }
];

// GENERATED

// GENERATED
class CompressedTextureDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = CompressedTexture;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CompressedTextureDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-compressedTexture',
                exportAs: 'ngtCompressedTexture',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: CompressedTextureDirective,
                    },
                ],
            },] }
];
CompressedTextureDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCompressedTextureModule {
}
ThreeCompressedTextureModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CompressedTextureDirective],
                imports: [CommonModule],
                exports: [CompressedTextureDirective],
            },] }
];

// GENERATED

// GENERATED
class CubeTextureDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = CubeTexture;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
CubeTextureDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-cubeTexture',
                exportAs: 'ngtCubeTexture',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: CubeTextureDirective,
                    },
                ],
            },] }
];
CubeTextureDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeCubeTextureModule {
}
ThreeCubeTextureModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CubeTextureDirective],
                imports: [CommonModule],
                exports: [CubeTextureDirective],
            },] }
];

// GENERATED

// GENERATED
class DataTextureDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = DataTexture;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DataTextureDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-dataTexture',
                exportAs: 'ngtDataTexture',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: DataTextureDirective,
                    },
                ],
            },] }
];
DataTextureDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeDataTextureModule {
}
ThreeDataTextureModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DataTextureDirective],
                imports: [CommonModule],
                exports: [DataTextureDirective],
            },] }
];

// GENERATED

// GENERATED
class DataTexture2DArrayDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = DataTexture2DArray;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DataTexture2DArrayDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-dataTexture2DArray',
                exportAs: 'ngtDataTexture2DArray',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: DataTexture2DArrayDirective,
                    },
                ],
            },] }
];
DataTexture2DArrayDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeDataTexture2DArrayModule {
}
ThreeDataTexture2DArrayModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DataTexture2DArrayDirective],
                imports: [CommonModule],
                exports: [DataTexture2DArrayDirective],
            },] }
];

// GENERATED

// GENERATED
class DataTexture3DDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = DataTexture3D;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DataTexture3DDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-dataTexture3D',
                exportAs: 'ngtDataTexture3D',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: DataTexture3DDirective,
                    },
                ],
            },] }
];
DataTexture3DDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeDataTexture3DModule {
}
ThreeDataTexture3DModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DataTexture3DDirective],
                imports: [CommonModule],
                exports: [DataTexture3DDirective],
            },] }
];

// GENERATED

// GENERATED
class DepthTextureDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = DepthTexture;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DepthTextureDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-depthTexture',
                exportAs: 'ngtDepthTexture',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: DepthTextureDirective,
                    },
                ],
            },] }
];
DepthTextureDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeDepthTextureModule {
}
ThreeDepthTextureModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DepthTextureDirective],
                imports: [CommonModule],
                exports: [DepthTextureDirective],
            },] }
];

// GENERATED

// GENERATED
class VideoTextureDirective extends ThreeTexture {
    constructor() {
        super(...arguments);
        this.textureType = VideoTexture;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
VideoTextureDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-videoTexture',
                exportAs: 'ngtVideoTexture',
                providers: [
                    {
                        provide: ThreeTexture,
                        useExisting: VideoTextureDirective,
                    },
                ],
            },] }
];
VideoTextureDirective.propDecorators = {
    args: [{ type: Input }]
};

// GENERATED
class ThreeVideoTextureModule {
}
ThreeVideoTextureModule.decorators = [
    { type: NgModule, args: [{
                declarations: [VideoTextureDirective],
                imports: [CommonModule],
                exports: [VideoTextureDirective],
            },] }
];

// GENERATED

// GENERATED

/**
 * Generated bundle index. Do not edit.
 */

export { CanvasTextureDirective, CompressedTextureDirective, CubeTextureDirective, DataTexture2DArrayDirective, DataTexture3DDirective, DataTextureDirective, DepthTextureDirective, ThreeCanvasTextureModule, ThreeCompressedTextureModule, ThreeCubeTextureModule, ThreeDataTexture2DArrayModule, ThreeDataTexture3DModule, ThreeDataTextureModule, ThreeDepthTextureModule, ThreeTexture, ThreeVideoTextureModule, VideoTextureDirective };
//# sourceMappingURL=angular-three-core-textures.js.map
