import { EventEmitter, NgZone, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import type { Object3D } from 'three';
import { AnimationStore, CanvasStore, EventsStore, InstancesStore } from '../stores';
import type { ThreeColor, ThreeEuler, ThreeEvent, ThreeQuaternion, ThreeVector3, UnknownRecord } from '../typings';
import { AnimationLoopParticipant } from './animation-loop-participant.abstract';
export declare abstract class ThreeObject3d<TObject extends Object3D = Object3D> extends AnimationLoopParticipant<TObject> implements OnDestroy, OnChanges {
    protected readonly canvasStore: CanvasStore;
    protected readonly instancesStore: InstancesStore;
    protected readonly eventsStore: EventsStore;
    readonly animationStore: AnimationStore;
    readonly ngZone: NgZone;
    protected readonly parentObjectDirective?: ThreeObject3d<Object3D> | undefined;
    name?: string;
    position?: ThreeVector3;
    rotation?: ThreeEuler;
    quaternion?: ThreeQuaternion;
    scale?: ThreeVector3;
    color?: ThreeColor;
    userData?: UnknownRecord;
    castShadow: boolean;
    receiveShadow: boolean;
    visible: boolean;
    matrixAutoUpdate: boolean;
    appendMode: 'immediate' | 'root';
    appendTo?: Object3D;
    click: EventEmitter<ThreeEvent<MouseEvent>>;
    contextmenu: EventEmitter<ThreeEvent<MouseEvent>>;
    dblclick: EventEmitter<ThreeEvent<MouseEvent>>;
    pointerup: EventEmitter<ThreeEvent<PointerEvent>>;
    pointerdown: EventEmitter<ThreeEvent<PointerEvent>>;
    pointerover: EventEmitter<ThreeEvent<PointerEvent>>;
    pointerout: EventEmitter<ThreeEvent<PointerEvent>>;
    pointerenter: EventEmitter<ThreeEvent<PointerEvent>>;
    pointerleave: EventEmitter<ThreeEvent<PointerEvent>>;
    pointermove: EventEmitter<ThreeEvent<PointerEvent>>;
    pointermissed: EventEmitter<ThreeEvent<PointerEvent>>;
    pointercancel: EventEmitter<ThreeEvent<PointerEvent>>;
    wheel: EventEmitter<ThreeEvent<WheelEvent>>;
    private $object3d;
    get object3d$(): Observable<TObject | null>;
    ready: Observable<TObject>;
    constructor(canvasStore: CanvasStore, instancesStore: InstancesStore, eventsStore: EventsStore, animationStore: AnimationStore, ngZone: NgZone, parentObjectDirective?: ThreeObject3d<Object3D> | undefined);
    ngOnChanges(changes: SimpleChanges): void;
    protected init(): void;
    protected addToScene(): void;
    protected addToParent(): void;
    protected remove(): void;
    protected objectReady(): void;
    private applyCustomProps;
    private applyEvents;
    private appendToParent;
    ngOnDestroy(): void;
    protected abstract initObject(): void;
    abstract get object3d(): TObject;
}
