import { OnDestroy } from '@angular/core';
import { Observable } from 'rxjs';
import { OrthographicCamera, PerspectiveCamera, Scene, WebGLRenderer, WebGLShadowMap } from 'three';
import type { CanvasInternal, CanvasStoreState, RaycasterOptions, Size, ThreeRaycaster } from '../typings';
import { ImperativeComponentStore } from './imperative-component-store.abstract';
interface WindowResizeEffectParams {
    size: Size;
    dpr: number;
}
export declare class CanvasStore extends ImperativeComponentStore<CanvasStoreState> implements OnDestroy {
    readonly renderer$: Observable<WebGLRenderer | undefined>;
    readonly camera$: Observable<OrthographicCamera | PerspectiveCamera | undefined>;
    readonly scene$: Observable<Scene | undefined>;
    readonly raycaster$: Observable<ThreeRaycaster | undefined>;
    readonly isOrthographic$: Observable<boolean>;
    readonly isLinear$: Observable<boolean>;
    readonly shadows$: Observable<boolean | Partial<WebGLShadowMap>>;
    readonly active$: Observable<boolean>;
    readonly canvasInternal$: Observable<CanvasInternal>;
    constructor();
    readonly setIsOrthographic: (observableOrValue: boolean | Observable<boolean>) => import("rxjs").Subscription;
    readonly setIsLinear: (observableOrValue: boolean | Observable<boolean>) => import("rxjs").Subscription;
    readonly setShadows: (observableOrValue: boolean | Partial<WebGLShadowMap> | Observable<boolean | Partial<WebGLShadowMap>>) => import("rxjs").Subscription;
    readonly setSize: (observableOrValue: Size | Observable<Size>) => import("rxjs").Subscription;
    readonly setDpr: (observableOrValue: number | Observable<number>) => import("rxjs").Subscription;
    readonly setActive: (observableOrValue: boolean | Observable<boolean>) => import("rxjs").Subscription;
    readonly initRendererEffect: (observableOrValue: HTMLCanvasElement | Observable<HTMLCanvasElement>) => import("rxjs").Subscription;
    readonly initSceneEffect: (observableOrValue: import("../typings").Overwrite<Partial<Pick<Scene, "toJSON" | "getWorldDirection" | "updateMatrixWorld" | "id" | "uuid" | "name" | "parent" | "children" | "up" | "position" | "rotation" | "quaternion" | "scale" | "modelViewMatrix" | "normalMatrix" | "matrix" | "matrixWorld" | "matrixAutoUpdate" | "matrixWorldNeedsUpdate" | "layers" | "visible" | "castShadow" | "receiveShadow" | "frustumCulled" | "renderOrder" | "animations" | "userData" | "customDepthMaterial" | "customDistanceMaterial" | "isObject3D" | "applyMatrix4" | "applyQuaternion" | "setRotationFromAxisAngle" | "setRotationFromEuler" | "setRotationFromMatrix" | "setRotationFromQuaternion" | "rotateOnAxis" | "rotateOnWorldAxis" | "rotateX" | "rotateY" | "rotateZ" | "translateOnAxis" | "translateX" | "translateY" | "translateZ" | "localToWorld" | "worldToLocal" | "lookAt" | "add" | "remove" | "clear" | "attach" | "getObjectById" | "getObjectByName" | "getObjectByProperty" | "getWorldPosition" | "getWorldQuaternion" | "getWorldScale" | "raycast" | "traverse" | "traverseVisible" | "traverseAncestors" | "updateMatrix" | "updateWorldMatrix" | "clone" | "copy" | "addEventListener" | "hasEventListener" | "removeEventListener" | "dispatchEvent" | "background" | "fog" | "overrideMaterial" | "autoUpdate" | "environment">>, import("../typings").ThreeCommonParameters> | Observable<import("../typings").Overwrite<Partial<Pick<Scene, "toJSON" | "getWorldDirection" | "updateMatrixWorld" | "id" | "uuid" | "name" | "parent" | "children" | "up" | "position" | "rotation" | "quaternion" | "scale" | "modelViewMatrix" | "normalMatrix" | "matrix" | "matrixWorld" | "matrixAutoUpdate" | "matrixWorldNeedsUpdate" | "layers" | "visible" | "castShadow" | "receiveShadow" | "frustumCulled" | "renderOrder" | "animations" | "userData" | "customDepthMaterial" | "customDistanceMaterial" | "isObject3D" | "applyMatrix4" | "applyQuaternion" | "setRotationFromAxisAngle" | "setRotationFromEuler" | "setRotationFromMatrix" | "setRotationFromQuaternion" | "rotateOnAxis" | "rotateOnWorldAxis" | "rotateX" | "rotateY" | "rotateZ" | "translateOnAxis" | "translateX" | "translateY" | "translateZ" | "localToWorld" | "worldToLocal" | "lookAt" | "add" | "remove" | "clear" | "attach" | "getObjectById" | "getObjectByName" | "getObjectByProperty" | "getWorldPosition" | "getWorldQuaternion" | "getWorldScale" | "raycast" | "traverse" | "traverseVisible" | "traverseAncestors" | "updateMatrix" | "updateWorldMatrix" | "clone" | "copy" | "addEventListener" | "hasEventListener" | "removeEventListener" | "dispatchEvent" | "background" | "fog" | "overrideMaterial" | "autoUpdate" | "environment">>, import("../typings").ThreeCommonParameters> | undefined> | undefined) => import("rxjs").Subscription;
    readonly initCameraEffect: (observableOrValue: OrthographicCamera | PerspectiveCamera | import("../typings").Overwrite<Partial<PerspectiveCamera>, import("../typings").ThreeCommonParameters> | import("../typings").Overwrite<Partial<OrthographicCamera>, import("../typings").ThreeCommonParameters> | Observable<OrthographicCamera | PerspectiveCamera | import("../typings").Overwrite<Partial<PerspectiveCamera>, import("../typings").ThreeCommonParameters> | import("../typings").Overwrite<Partial<OrthographicCamera>, import("../typings").ThreeCommonParameters> | undefined> | undefined) => import("rxjs").Subscription;
    readonly initRaycasterEffect: (observableOrValue: RaycasterOptions | Observable<RaycasterOptions | undefined> | undefined) => import("rxjs").Subscription;
    readonly windowResizeEffect: (observableOrValue: WindowResizeEffectParams | Observable<WindowResizeEffectParams>) => import("rxjs").Subscription;
    ngOnDestroy(): void;
}
export {};
